aboutsummaryrefslogtreecommitdiff
path: root/gcc/alias.c
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/alias.c')
-rw-r--r--gcc/alias.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/gcc/alias.c b/gcc/alias.c
index 68a8272..914b153 100644
--- a/gcc/alias.c
+++ b/gcc/alias.c
@@ -2199,8 +2199,8 @@ canon_true_dependence (mem, mem_mode, mem_addr, x, varies)
varies);
}
-/* Returns non-zero if a write to X might alias a previous read from
- (or, if WRITEP is non-zero, a write to) MEM. */
+/* Returns nonzero if a write to X might alias a previous read from
+ (or, if WRITEP is nonzero, a write to) MEM. */
static int
write_dependence_p (mem, x, writep)
@@ -2389,7 +2389,7 @@ nonlocal_mentioned_p_1 (loc, data)
return 0;
}
/* Returns non-zero if X might mention something which is not
local to the function and is not constant. */
static int
@@ -2487,7 +2487,7 @@ nonlocal_referenced_p_1 (loc, data)
return 0;
}
/* Returns non-zero if X might reference something which is not
local to the function and is not constant. */
static int
@@ -2567,7 +2567,7 @@ nonlocal_set_p_1 (loc, data)
return 0;
}
/* Returns non-zero if X might set something which is not
local to the function and is not constant. */
static int
@@ -2389,7 +2389,7 @@ nonlocal_mentioned_p_1 (loc, data)
return 0;
}
-/* Returns non-zero if X might mention something which is not
+/* Returns nonzero if X might mention something which is not
local to the function and is not constant. */
static int
@@ -2487,7 +2487,7 @@ nonlocal_referenced_p_1 (loc, data)
return 0;
}
-/* Returns non-zero if X might reference something which is not
+/* Returns nonzero if X might reference something which is not
local to the function and is not constant. */
static int
@@ -2567,7 +2567,7 @@ nonlocal_set_p_1 (loc, data)
return 0;
}
-/* Returns non-zero if X might set something which is not
+/* Returns nonzero if X might set something which is not
local to the function and is not constant. */
static int